# coding: utf-8

# flake8: noqa

"""
    Lance Namespace Specification

    This OpenAPI specification is a part of the Lance namespace specification. It contains 2 parts:  The `components/schemas`, `components/responses`, `components/examples`, `tags` sections define the request and response shape for each operation in a Lance Namespace across all implementations. See https://lancedb.github.io/lance-namespace/spec/operations for more details.  The `servers`, `security`, `paths`, `components/parameters` sections are for the  Lance REST Namespace implementation, which defines a complete REST server that can work with Lance datasets. See https://lancedb.github.io/lance-namespace/spec/impls/rest for more details. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.0.21"

# import apis into sdk package
from lance_namespace_urllib3_client.api.data_api import DataApi
from lance_namespace_urllib3_client.api.index_api import IndexApi
from lance_namespace_urllib3_client.api.metadata_api import MetadataApi
from lance_namespace_urllib3_client.api.namespace_api import NamespaceApi
from lance_namespace_urllib3_client.api.table_api import TableApi
from lance_namespace_urllib3_client.api.tag_api import TagApi
from lance_namespace_urllib3_client.api.transaction_api import TransactionApi

# import ApiClient
from lance_namespace_urllib3_client.api_response import ApiResponse
from lance_namespace_urllib3_client.api_client import ApiClient
from lance_namespace_urllib3_client.configuration import Configuration
from lance_namespace_urllib3_client.exceptions import OpenApiException
from lance_namespace_urllib3_client.exceptions import ApiTypeError
from lance_namespace_urllib3_client.exceptions import ApiValueError
from lance_namespace_urllib3_client.exceptions import ApiKeyError
from lance_namespace_urllib3_client.exceptions import ApiAttributeError
from lance_namespace_urllib3_client.exceptions import ApiException

# import models into sdk package
from lance_namespace_urllib3_client.models.alter_table_add_columns_request import AlterTableAddColumnsRequest
from lance_namespace_urllib3_client.models.alter_table_add_columns_response import AlterTableAddColumnsResponse
from lance_namespace_urllib3_client.models.alter_table_alter_columns_request import AlterTableAlterColumnsRequest
from lance_namespace_urllib3_client.models.alter_table_alter_columns_response import AlterTableAlterColumnsResponse
from lance_namespace_urllib3_client.models.alter_table_drop_columns_request import AlterTableDropColumnsRequest
from lance_namespace_urllib3_client.models.alter_table_drop_columns_response import AlterTableDropColumnsResponse
from lance_namespace_urllib3_client.models.alter_transaction_action import AlterTransactionAction
from lance_namespace_urllib3_client.models.alter_transaction_request import AlterTransactionRequest
from lance_namespace_urllib3_client.models.alter_transaction_response import AlterTransactionResponse
from lance_namespace_urllib3_client.models.alter_transaction_set_property import AlterTransactionSetProperty
from lance_namespace_urllib3_client.models.alter_transaction_set_status import AlterTransactionSetStatus
from lance_namespace_urllib3_client.models.alter_transaction_unset_property import AlterTransactionUnsetProperty
from lance_namespace_urllib3_client.models.analyze_table_query_plan_request import AnalyzeTableQueryPlanRequest
from lance_namespace_urllib3_client.models.analyze_table_query_plan_response import AnalyzeTableQueryPlanResponse
from lance_namespace_urllib3_client.models.boolean_query import BooleanQuery
from lance_namespace_urllib3_client.models.boost_query import BoostQuery
from lance_namespace_urllib3_client.models.column_alteration import ColumnAlteration
from lance_namespace_urllib3_client.models.count_table_rows_request import CountTableRowsRequest
from lance_namespace_urllib3_client.models.create_empty_table_request import CreateEmptyTableRequest
from lance_namespace_urllib3_client.models.create_empty_table_response import CreateEmptyTableResponse
from lance_namespace_urllib3_client.models.create_namespace_request import CreateNamespaceRequest
from lance_namespace_urllib3_client.models.create_namespace_response import CreateNamespaceResponse
from lance_namespace_urllib3_client.models.create_table_index_request import CreateTableIndexRequest
from lance_namespace_urllib3_client.models.create_table_index_response import CreateTableIndexResponse
from lance_namespace_urllib3_client.models.create_table_request import CreateTableRequest
from lance_namespace_urllib3_client.models.create_table_response import CreateTableResponse
from lance_namespace_urllib3_client.models.create_table_tag_request import CreateTableTagRequest
from lance_namespace_urllib3_client.models.delete_from_table_request import DeleteFromTableRequest
from lance_namespace_urllib3_client.models.delete_from_table_response import DeleteFromTableResponse
from lance_namespace_urllib3_client.models.delete_table_tag_request import DeleteTableTagRequest
from lance_namespace_urllib3_client.models.deregister_table_request import DeregisterTableRequest
from lance_namespace_urllib3_client.models.deregister_table_response import DeregisterTableResponse
from lance_namespace_urllib3_client.models.describe_namespace_request import DescribeNamespaceRequest
from lance_namespace_urllib3_client.models.describe_namespace_response import DescribeNamespaceResponse
from lance_namespace_urllib3_client.models.describe_table_index_stats_request import DescribeTableIndexStatsRequest
from lance_namespace_urllib3_client.models.describe_table_index_stats_response import DescribeTableIndexStatsResponse
from lance_namespace_urllib3_client.models.describe_table_request import DescribeTableRequest
from lance_namespace_urllib3_client.models.describe_table_response import DescribeTableResponse
from lance_namespace_urllib3_client.models.describe_transaction_request import DescribeTransactionRequest
from lance_namespace_urllib3_client.models.describe_transaction_response import DescribeTransactionResponse
from lance_namespace_urllib3_client.models.drop_namespace_request import DropNamespaceRequest
from lance_namespace_urllib3_client.models.drop_namespace_response import DropNamespaceResponse
from lance_namespace_urllib3_client.models.drop_table_index_request import DropTableIndexRequest
from lance_namespace_urllib3_client.models.drop_table_index_response import DropTableIndexResponse
from lance_namespace_urllib3_client.models.drop_table_request import DropTableRequest
from lance_namespace_urllib3_client.models.drop_table_response import DropTableResponse
from lance_namespace_urllib3_client.models.error_response import ErrorResponse
from lance_namespace_urllib3_client.models.explain_table_query_plan_request import ExplainTableQueryPlanRequest
from lance_namespace_urllib3_client.models.explain_table_query_plan_response import ExplainTableQueryPlanResponse
from lance_namespace_urllib3_client.models.fts_query import FtsQuery
from lance_namespace_urllib3_client.models.get_table_stats_request import GetTableStatsRequest
from lance_namespace_urllib3_client.models.get_table_stats_response import GetTableStatsResponse
from lance_namespace_urllib3_client.models.get_table_tag_version_request import GetTableTagVersionRequest
from lance_namespace_urllib3_client.models.get_table_tag_version_response import GetTableTagVersionResponse
from lance_namespace_urllib3_client.models.index_content import IndexContent
from lance_namespace_urllib3_client.models.insert_into_table_request import InsertIntoTableRequest
from lance_namespace_urllib3_client.models.insert_into_table_response import InsertIntoTableResponse
from lance_namespace_urllib3_client.models.json_arrow_data_type import JsonArrowDataType
from lance_namespace_urllib3_client.models.json_arrow_field import JsonArrowField
from lance_namespace_urllib3_client.models.json_arrow_schema import JsonArrowSchema
from lance_namespace_urllib3_client.models.list_namespaces_request import ListNamespacesRequest
from lance_namespace_urllib3_client.models.list_namespaces_response import ListNamespacesResponse
from lance_namespace_urllib3_client.models.list_table_indices_request import ListTableIndicesRequest
from lance_namespace_urllib3_client.models.list_table_indices_response import ListTableIndicesResponse
from lance_namespace_urllib3_client.models.list_table_tags_response import ListTableTagsResponse
from lance_namespace_urllib3_client.models.list_table_versions_request import ListTableVersionsRequest
from lance_namespace_urllib3_client.models.list_table_versions_response import ListTableVersionsResponse
from lance_namespace_urllib3_client.models.list_tables_request import ListTablesRequest
from lance_namespace_urllib3_client.models.list_tables_response import ListTablesResponse
from lance_namespace_urllib3_client.models.match_query import MatchQuery
from lance_namespace_urllib3_client.models.merge_insert_into_table_request import MergeInsertIntoTableRequest
from lance_namespace_urllib3_client.models.merge_insert_into_table_response import MergeInsertIntoTableResponse
from lance_namespace_urllib3_client.models.multi_match_query import MultiMatchQuery
from lance_namespace_urllib3_client.models.namespace_exists_request import NamespaceExistsRequest
from lance_namespace_urllib3_client.models.new_column_transform import NewColumnTransform
from lance_namespace_urllib3_client.models.operator import Operator
from lance_namespace_urllib3_client.models.phrase_query import PhraseQuery
from lance_namespace_urllib3_client.models.query_table_request import QueryTableRequest
from lance_namespace_urllib3_client.models.query_table_request_full_text_query import QueryTableRequestFullTextQuery
from lance_namespace_urllib3_client.models.query_table_request_vector import QueryTableRequestVector
from lance_namespace_urllib3_client.models.register_table_request import RegisterTableRequest
from lance_namespace_urllib3_client.models.register_table_response import RegisterTableResponse
from lance_namespace_urllib3_client.models.restore_table_request import RestoreTableRequest
from lance_namespace_urllib3_client.models.restore_table_response import RestoreTableResponse
from lance_namespace_urllib3_client.models.set_property_mode import SetPropertyMode
from lance_namespace_urllib3_client.models.string_fts_query import StringFtsQuery
from lance_namespace_urllib3_client.models.structured_fts_query import StructuredFtsQuery
from lance_namespace_urllib3_client.models.table_exists_request import TableExistsRequest
from lance_namespace_urllib3_client.models.table_version import TableVersion
from lance_namespace_urllib3_client.models.tag_contents import TagContents
from lance_namespace_urllib3_client.models.transaction_status import TransactionStatus
from lance_namespace_urllib3_client.models.unset_property_mode import UnsetPropertyMode
from lance_namespace_urllib3_client.models.update_table_request import UpdateTableRequest
from lance_namespace_urllib3_client.models.update_table_response import UpdateTableResponse
from lance_namespace_urllib3_client.models.update_table_tag_request import UpdateTableTagRequest
